@@ -761,11 +761,11 @@ sub debugging {
     my @args = @_;
 
     if (@args) {
-        if ($args[0] =~ /^on|1$/i) {
+        if ($args[0] =~ /^(on|1)$/i) {
             $self->{ DEBUG_DIRS } = 1;
             shift(@args);
         }
-        elsif ($args[0] =~ /^off|0$/i) {
+        elsif ($args[0] =~ /^(off|0)$/i) {
             $self->{ DEBUG_DIRS } = 0;
             shift(@args);
         }
