@@ -744,6 +744,8 @@ sub define_block {
     $self->debug("compiled block '$name':\n$block")
         if $self->{ DEBUG } & Template::Constants::DEBUG_PARSER;
 
+    warn "Block redefined: $name\n" if exists $defblock->{ $name };
+
     $defblock->{ $name } = $block;
 
     return undef;
@@ -952,22 +954,27 @@ sub _parse {
             or $status = ACCEPT;
 
         # use dummy sub if code ref doesn't exist
-        $code = sub { $_[1] }
-            unless $code;
+        if ( !$code ) {
+            $coderet = $len ? $stack->[ -$len ]->[1] : undef;
+        } else {
+            # $code = sub { $_[1] }
+            #     unless $code;
 
-        @codevars = $len
-                ?   map { $_->[1] } @$stack[ -$len .. -1 ]
-                :   ();
+            @codevars = $len
+                    ?   map { $_->[1] } @$stack[ -$len .. -1 ]
+                    :   ();
 
-        eval {
-            $coderet = &$code( $self, @codevars );
-        };
-        if ($@) {
-            my $err = $@;
-            chomp $err;
-            return $self->_parse_error($err);
+            eval {
+                $coderet = &$code( $self, @codevars );
+            };
+            if ($@) {
+                my $err = $@;
+                chomp $err;
+                return $self->_parse_error($err);
+            }
         }
 
+
         # reduce stack by $len
         splice(@$stack, -$len, $len);
 
